@@ -89,9 +89,42 @@ def tensorleap_load_model(prediction_types: Optional[List[PredictionTypeHandler]
                     ret = self.model(arg)
                     return ret.numpy()
 
+                def _convert_onnx_inputs_to_correct_type(
+                        self, float_arrays_inputs: Dict[str, np.ndarray]
+                ) -> Dict[str, np.ndarray]:
+                    """
+                    Cast user-provided NumPy inputs to match the dtypes/shapes
+                    expected by an ONNX Runtime InferenceSession.
+                    """
+                    coerced = {}
+                    meta = {i.name: i for i in self.model.get_inputs()}
+
+                    for name, arr in float_arrays_inputs.items():
+                        if name not in meta:
+                            # Keep as-is unless extra inputs are disallowed
+                            coerced[name] = arr
+                            continue
+
+                        info = meta[name]
+                        want_dtype = np.dtype(info.type)  # ONNX Runtime gives NumPy dtype string
+
+                        # Cast dtype if needed
+                        if arr.dtype != want_dtype:
+                            arr = arr.astype(want_dtype, copy=False)
+
+                        coerced[name] = arr
+
+                    # Verify required inputs are present
+                    missing = [n for n in meta if n not in coerced]
+                    if missing:
+                        raise KeyError(f"Missing required input(s): {sorted(missing)}")
+
+                    return coerced
+
                 # onnx runtime interface
                 def run(self, output_names, input_dict):
-                    return self.model.run(output_names, input_dict)
+                    corrected_type_inputs = self._convert_onnx_inputs_to_correct_type(input_dict)
+                    return self.model.run(output_names, corrected_type_inputs)
 
                 def get_inputs(self):
                     return self.model.get_inputs()
@@ -577,6 +610,7 @@ def tensorleap_element_instance_preprocess(
                     for instance_id in instances_ids:
                         instance_to_sample_ids_mappings[instance_id] = sample_id
                     all_sample_ids.extend(instances_ids)
+                preprocess_response.length = len(all_sample_ids)
                 preprocess_response.sample_ids_to_instance_mappings = sample_ids_to_instance_mappings
                 preprocess_response.instance_to_sample_ids_mappings = instance_to_sample_ids_mappings
                 preprocess_response.sample_ids = all_sample_ids
